@@ -1,5 +1,5 @@
 /* blurbs.h - warranty and conditions blurbs
-   Copyright (C) 2011-2016 Simon Josefsson
+   Copyright (C) 2011-2019 Simon Josefsson, Tim Ruehsen
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -15,6 +15,12 @@
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
+#define GREETING							\
+  "Copyright (C) 2011-2019  Simon Josefsson, Tim Ruehsen\n"				\
+  "This program comes with ABSOLUTELY NO WARRANTY; for details type `show w'.\n" \
+  "This is free software, and you are welcome to redistribute it\n"	\
+  "under certain conditions; type `show c' for details.\n\n"
+
 #define WARRANTY							\
   "THERE IS NO WARRANTY FOR THE PROGRAM, TO THE EXTENT PERMITTED BY\n"	\
   "APPLICABLE LAW.  EXCEPT WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT\n" \
